@@ -297,7 +297,7 @@ def write_table(
     if insert_mode == "overwrite" and table_exists:
         truncate_table(spark=spark, table_name=f"{db_name}.{table_name}")
 
-    if sort_fields and upsert_fields:
+    if sort_fields and upsert_fields and insert_mode=="upsert":
         if table_exists:
             print(
                 f"TABLE EXIST - upsert_fields: {upsert_fields} - sort_fields: {sort_fields}"
@@ -352,8 +352,10 @@ def __save_database_profile(profile_js, layer, spark=None):
         table = "cortex.data_governance_quality.bronze_profile"
     elif layer == "silver":
         table = "cortex.data_governance_quality.silver_profile"
-    else:
+    elif layer == "gold":
         table = "cortex.data_governance_quality.gold_profile"
+    else:
+        table = "cortex.data_governance_quality.diamond_profile"
 
     if spark is None:
         spark = get_spark_session("upsert_data")
@@ -481,6 +483,7 @@ def landing_to_bronze(
     profiling=False,
     infer_schema=False,
     reset_checkpoint=False,
+    table_owner='data-production',
     catalog_name=None,
     output_db_name=None,
     tbl_properties=None,
@@ -573,8 +576,9 @@ def landing_to_bronze(
 
     db_table = f"{db_name}.{dataset_name}"
 
+    
     if catalog_name != "hive_metastore":
-        set_owner_to(spark, db_table, "data-production")
+        set_owner_to(spark, db_table, table_owner)
 
     if tbl_properties:
         set_tbl_properties(spark, db_table, tbl_properties)
@@ -611,6 +615,7 @@ def bronze_to_silver(
     processing_function=None,
     processing_function_args=None,
     processing_function_kwargs=None,
+    table_owner='data-production',
     profiling=False,
     reset_checkpoint=False,
     catalog_name=None,
@@ -685,7 +690,7 @@ def bronze_to_silver(
     output_db_table = f"{output_db_name}.{dataset_name}"
 
     if catalog_name != "hive_metastore":
-        set_owner_to(spark, output_db_table, "data-production")
+        set_owner_to(spark, output_db_table, table_owner)
 
     if tbl_properties:
         set_tbl_properties(spark, output_db_table, tbl_properties)
@@ -714,6 +719,7 @@ def silver_to_gold(
     processing_function=None,
     processing_function_args=None,
     processing_function_kwargs=None,
+    table_owner='data-production',
     profiling=False,
     sort_fields: list = None,
     upsert_fields: list = None,
@@ -788,7 +794,7 @@ def silver_to_gold(
     output_db_table = f"{output_db_name}.{dataset_name}"
 
     if catalog_name != "hive_metastore":
-        set_owner_to(spark, output_db_table, "data-production")
+        set_owner_to(spark, output_db_table, table_owner)
 
     if tbl_properties:
         set_tbl_properties(spark, output_db_table, tbl_properties)
@@ -814,6 +820,7 @@ def gold_to_diamond(
     processing_function=None,
     processing_function_args=None,
     processing_function_kwargs=None,
+    table_owner='data-production',
     profiling=False,
     sort_fields: list = None,
     upsert_fields: list = None,
@@ -888,7 +895,7 @@ def gold_to_diamond(
     output_db_table = f"{output_db_name}.{dataset_name}"
 
     if catalog_name != "hive_metastore":
-        set_owner_to(spark, output_db_table, "data-production")
+        set_owner_to(spark, output_db_table, table_owner)
 
     if tbl_properties:
         set_tbl_properties(spark, output_db_table, tbl_properties)
